@@ -80,8 +80,8 @@ def main():
     format = args.format
     output = args.output
     distance = args.distance
-    starttime = args.starttime if args.starttime else None
-    endtime = args.endtime if args.endtime else None
+    starttime = args.starttime
+    endtime = args.endtime
     seed = args.randomseed
     verbose = args.verbose
 
